@@ -2,7 +2,7 @@ import requests
 import json
 
 def create(uploadType, shot, resourceId, filePath):
-    url = "http://3.39.12.67:8083/job"
+    url = "http://3.39.12.67:8083/qcc/job"
 
     headers = {
         #"Content-Type": "application/x-www-form-urlencoded"
@@ -12,8 +12,8 @@ def create(uploadType, shot, resourceId, filePath):
     data = json.dumps({
         "uploadType": uploadType,
         "shot": shot,
-        "resourceId": 1,
-        "filePath": "filePath"
+        "resourceId": resourceId,
+        "filePath": filePath
     })
 
     # params = {
@@ -27,7 +27,7 @@ def create(uploadType, shot, resourceId, filePath):
     return response.text
 
 def getList(volumeName, hostPath):
-    url = "http://3.39.12.67:8083/jobs"
+    url = "http://3.39.12.67:8083/qcc/jobs"
 
     # params = {
     #     "volumeName": volumeName,
