@@ -3,7 +3,7 @@ import requests
 def getResource():
     url = "http://3.39.12.67:8083/qcc/jobs"
 
-    response = requests.get(f"{url}", headers=headers) # , params=params)
+    response = requests.get(f"{url}") # , params=params)
 
     print("[LIST] ", response.text, flush=True)
 
